@@ -1,20 +1,7 @@
 /*
-    Copyright 2011 John Layt <john@layt.net>
+    SPDX-FileCopyrightText: 2011 John Layt <john@layt.net>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KTIMECOMBOBOX_H
@@ -24,8 +11,7 @@
 
 #include <QComboBox>
 #include <QLocale>
-
-class KTimeComboBoxPrivate;
+#include <memory>
 
 /**
  * @class KTimeComboBox ktimecombobox.h KTimeComboBox
@@ -43,7 +29,6 @@ class KWIDGETSADDONS_EXPORT KTimeComboBox : public QComboBox
     Q_PROPERTY(Options options READ options WRITE setOptions)
 
 public:
-
     /**
      * Options provided by the widget
      * @see options
@@ -51,10 +36,10 @@ public:
      * @see Options
      */
     enum Option {
-        EditTime         = 0x0001,  /**< Allow the user to manually edit the time in the combo line edit */
-        SelectTime       = 0x0002,  /**< Allow the user to select the time from a drop-down menu */
-        ForceTime        = 0x0004,  /**< Any set or entered time will be forced to one of the drop-down times */
-        WarnOnInvalid    = 0x0008   /**< Show a warning box on focus out if the user enters an invalid time */
+        EditTime = 0x0001, /**< Allow the user to manually edit the time in the combo line edit */
+        SelectTime = 0x0002, /**< Allow the user to select the time from a drop-down menu */
+        ForceTime = 0x0004, /**< Any set or entered time will be forced to one of the drop-down times */
+        WarnOnInvalid = 0x0008, /**< Show a warning box on focus out if the user enters an invalid time */
     };
     /**
      * Stores a combination of #Option values.
@@ -149,10 +134,7 @@ public:
      * @param minWarnMsg the minimum warning message
      * @param maxWarnMsg the maximum warning message
      */
-    void setTimeRange(const QTime &minTime,
-                      const QTime &maxTime,
-                      const QString &minWarnMsg = QString(),
-                      const QString &maxWarnMsg = QString());
+    void setTimeRange(const QTime &minTime, const QTime &maxTime, const QString &minWarnMsg = QString(), const QString &maxWarnMsg = QString());
 
     /**
      * Reset the minimum and maximum time to the default values.
@@ -311,12 +293,9 @@ public Q_SLOTS:
      *
      * @see timeList()
      */
-    void setTimeList(QList<QTime> timeList,
-                     const QString &minWarnMsg = QString(),
-                     const QString &maxWarnMsg = QString());
+    void setTimeList(QList<QTime> timeList, const QString &minWarnMsg = QString(), const QString &maxWarnMsg = QString());
 
 protected:
-
     bool eventFilter(QObject *object, QEvent *event) override;
     void showPopup() override;
     void hidePopup() override;
@@ -337,14 +316,12 @@ protected:
     virtual void assignTime(const QTime &time);
 
 private:
-
     friend class KTimeComboBoxPrivate;
-    KTimeComboBoxPrivate *const d;
+    std::unique_ptr<class KTimeComboBoxPrivate> const d;
 
     Q_PRIVATE_SLOT(d, void selectTime(int index))
     Q_PRIVATE_SLOT(d, void enterTime(const QTime &))
     Q_PRIVATE_SLOT(d, void parseTime())
-
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KTimeComboBox::Options)
